/*
  license GPL v3 ...........

  description of this file:
  a page for viewing a user selected RSS feed ;

  Architecture:
  page
  {
    ToolbarActions

    Rectangle
    {
        label(RSS feed title)
    }

    ListView
    {
    }

    Component(delegate)

    XmlListModel(rss feed)
  }
*/

import QtQuick 2.0
import QtQuick.XmlListModel 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

Page {
    id: page_feed
//    width: 100
//    height: 62
    property string rssmodel_url: ""
    property string rsstitle: ""
    property int rssIndex: 0
    property variant rss_model

    onRssIndexChanged:
    {
        rss_listview.currentIndex = rssIndex
        rss_listview.positionViewAtIndex(rss_listview.currentIndex, ListView.Center)
        // console.log("rss_listview.currentIndex: ", rss_listview.currentIndex)
    }

    function setFeed(model, index)
    {
        console.log("Input index: ", index)
        rss_model = model
        rssIndex = index
    }

    tools: ToolbarItems {
        id: toolbar

        ToolbarButton {
            action: Action {
                text:  i18n.tr("index 0")
                iconSource: Qt.resolvedUrl("avatar.png")
                onTriggered:
                {
                    rss_listview.currentIndex = 10
                }
            }
        }

        ToolbarButton {
            action: Action {
                text:  i18n.tr("index 1")
                iconSource: Qt.resolvedUrl("avatar.png")
                onTriggered:
                {
                    rss_listview.currentIndex = 20
                }
            }
        }

        ToolbarButton {
            action: Action {
                text:  i18n.tr("Open site")
                iconSource: Qt.resolvedUrl("avatar.png")
                onTriggered:
                {
                    console.log("Open site", rss_listview.model.get(rss_listview.currentIndex).link)
                    Qt.openUrlExternally(rss_listview.model.get(rss_listview.currentIndex).link)
                }
            }
        }
    }

//    Rectangle
//    {
//        id: bg
//        anchors.fill: parent
//        color: "white"
//    }

    //////////////////////////////////////////////      shows the RSS feed title
    Rectangle
    {
        id: rec_title
        width: parent.width
        height: label_title.height + units.gu(1)
        color: "orange"

        Label
        {
            id: label_title
            anchors.centerIn: parent
            width: parent.width - units.gu(2)
//            ItemStyle.class: "title"
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            text: rsstitle
            fontSize: "large"
            color: "white"
        }
    }

    //////////////////////////////////////////////      a listview to show the RSS content
    ListView
    {
        id: rss_listview
        width: parent.width
        anchors.bottom: parent.bottom
        anchors.bottomMargin: units.gu(1)
        anchors.top: rec_title.bottom
        anchors.topMargin: units.gu(2)
        snapMode: ListView.SnapOneItem
//        height: isList ? 0 : units.gu(30)
//        opacity: isList ? 0 : 1
        cacheBuffer: 90
//        spacing: units.gu(2)
        boundsBehavior: Flickable.StopAtBounds
        orientation: ListView.Horizontal
//        currentIndex: rss_index
        contentHeight: parent.width * count
        model: rss_model
        delegate: xmldelegate
        highlightFollowsCurrentItem: true
        highlightRangeMode: ListView.StrictlyEnforceRange

        onCurrentIndexChanged:
        {
            console.log("ListView onCurrentIndexChanged", currentIndex)
            rsstitle = rss_listview.model.get(currentIndex).feed_name
        }
    }

    //////////////////////////////////////////////      delegate for ListView
    Component
    {
        id: xmldelegate

        Column
        {
            spacing: units.gu(2)
            width: rss_listview.width
            height: rss_listview.height

            Label
            {
                fontSize: "large"
                text: title
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width - units.gu(2)
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                color: "black"
            }

            Label
            {
                text:
                {
//                    if (description.split("</a>").length > 1)
//                        return description.split("</a>")[1].split("</p>")[0] ;
//                    else
                        return description ;
                }
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width - units.gu(1)
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                color: "black"

                MouseArea
                {
                    anchors.fill: parent
                    onClicked:
                    {
                        console.log("current index : " + index) ;
//                        rss_listview.currentIndex = 30
                    }
                }
            }
        }

    }

    //////////////////////////////////////////////////       RSS xml model
//    XmlListModel
//    {
//        id: rssmodel
//        source: ""
//        query: "/rss/channel/item"

//        XmlRole { name: "model_title"; query: "title/string()" }
//        XmlRole { name: "description"; query: "description/string()" }
//    }
}
