import QtQuick 2.0
import QtQuick.XmlListModel 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1

import "databasemodule_v2.js" as DB

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    id: mainView
    objectName: "mainView"
    applicationName: "RSS reader"

    width: units.gu(50)
    height: units.gu(75)

    Component.onCompleted:
    {
        //////////////////////////////////////////////////////////////  below DB operation is for avoid empty db
        var feeds = DB.loadFeeds();
        if (feeds.rows.length < 1)
        {
            DB.addFeed("" , "http://news.yahoo.com/rss/topstories");
            DB.addFeed("" , "http://news.yahoo.com/rss/tech");
            DB.addFeed("" , "http://www.engadget.com/rss.xml");
            DB.addTag("news");
            DB.addTag("tech");
            DB.addTag("engadget");
            DB.addFeedTag(1, 1) ;
            DB.addFeedTag(2, 2) ;
            DB.addFeedTag(3, 3) ;
            refresh() ;
        }

        else repeater.reloadTabs() ;     // load tabs from db
    }

    function refresh()             //  download all articles
    {
        var feeds = DB.loadFeeds();
        console.log(JSON.stringify(feeds));
        console.log(JSON.stringify(feeds.rows.item(0)));
        var feedarray = [] ;
        for (var i=0; i< feeds.rows.length; i++)
        {
            //            console.log(JSON.stringify(feeds.rows.item(i)));
            feedarray.push(feeds.rows.item(i));
        }
        //        console.log(JSON.stringify(feedarray));
        xmlnetwork.addFeedList(feedarray);
    }

    function toRssPage(model, index)     //   go to single article page     // bugs remain
    {
        feed_page.setFeed(model, index)
        pageStack.push(feed_page)
    }

    PageStack {
        id: pageStack
        anchors.fill: parent

        Component.onCompleted:
        {
            push(tabs);                      // use tabs as first page
        }

        Tabs {
            id: tabs
            anchors.fill: parent
            anchors.topMargin: units.gu(3)
            anchors.bottomMargin: units.gu(7)

            Tab {
                objectName: "Tab0"

                title: i18n.tr("Shorts")
                page: Page {
                    anchors.margins: units.gu(2)

                    tools: ToolbarItems {
                        id: toolbar

                        ToolbarButton {
                            action: Action {
                                text:  i18n.tr("Refresh")
                                iconSource: Qt.resolvedUrl("avatar.png")
                                onTriggered:
                                {
                                    refresh();
                                    toolbar.opened = false;
                                }
                            }
                        }
                    }

                    Component.onCompleted: shorts_view.reload() ;

                    ListColumnView
                    {
                        id: shorts_view
                        isAll: true
                    }
                }
            }

            Repeater
            {
                id: repeater
                model: 0
                TopicTab{  }

                function reloadTabs()
                {
                    repeater.model = 0 ;
                    var tags = DB.loadTags()
                    repeater.model = tags.rows.length ;
                    for (var i=0; i< tags.rows.length; i++)
                    {
                        console.log(JSON.stringify(tags.rows.item(i)));
                        repeater.itemAt(i).title = tags.rows.item(i).name ;
                        repeater.itemAt(i).tag_id = tags.rows.item(i).id ;
                        repeater.itemAt(i).isAll = false ;
                        repeater.itemAt(i).reload() ;
                    }
                }
            }
        }

        // independent page for viewing one RSS feed
        RssFeedPage
        {
            id: feed_page
            visible: false
        }
    }

    XmlNetwork         //  all download and xml parse functions here
    {
        id: xmlnetwork

        onDownloadFinish:
        {
            //            griddemo.reload();
            shorts_view.reload() ;
            repeater.reloadTabs() ;
        }
    }
}
